@@ -41,9 +41,7 @@
 #include "messagebox.h"
 #include "renderer.h"
 #include "shuffle.h"
-#include "speeds.h"
 #include "patsolve/solverinterface.h"
-#include "view.h"
 
 #include "KCardTheme"
 
@@ -1075,9 +1073,15 @@ void DealerScene::mouseReleaseEvent( QGraphicsSceneMouseEvent * e )
 
 void DealerScene::mouseDoubleClickEvent( QGraphicsSceneMouseEvent * e )
 {
-    stop();
-
-    KCardScene::mouseDoubleClickEvent( e );
+    if ( !m_dealHasBeenWon )
+    {
+        stop();
+        KCardScene::mouseDoubleClickEvent( e );
+    }
+    else
+    {
+        Q_EMIT newDeal();
+    }
 }
 
 
