@@ -49,6 +49,7 @@
 #include <KLocalizedString>
 #include <KDBusService>
 
+#include <QRandomGenerator>
 #include <QFile>
 #include <QTime>
 #include <QElapsedTimer>
@@ -56,7 +57,6 @@
 
 #include <Kdelibs4ConfigMigrator>
 #include <climits>
-#include <ctime>
 #include <QStandardPaths>
 #include <QApplication>
 #include <QCommandLineParser>
@@ -64,8 +64,8 @@
 
 static DealerScene *getDealer( int wanted_game , const QString & name )
 {
-    foreach ( DealerInfo * di, DealerInfoList::self()->games() )
-    {
+    const auto games = DealerInfoList::self()->games();
+    for (DealerInfo * di : games) {
         if ( (wanted_game < 0) ? (QString::fromUtf8(di->untranslatedBaseName()) == name) : di->providesId( wanted_game ) )
         {
             DealerScene * d = di->createGame();
@@ -114,7 +114,7 @@ int main( int argc, char **argv )
 
     KAboutData aboutData( QStringLiteral("kpat"),
                           i18n("KPatience"),
-                          KPAT_VERSION_STRING,
+                          QStringLiteral(KPAT_VERSION_STRING),
                           i18n("KDE Patience Game"),
                           KAboutLicense::GPL_V2,
                           i18n("© 1995 Paul Olav Tvete\n© 2000 Stephan Kulow"),
@@ -175,8 +175,8 @@ int main( int argc, char **argv )
     // the names of the game types in the help text.
     QMap<QString, int> indexMap;
     QStringList gameList;
-    foreach ( const DealerInfo *di, DealerInfoList::self()->games() )
-    {
+    const auto games = DealerInfoList::self()->games();
+    for (const DealerInfo *di : games) {
         KLocalizedString localizedKey = ki18n( di->untranslatedBaseName().constData() );
         //QT5 const QString translatedKey = lowerAlphaNum( localizedKey.toString( tmpLocale ) );
         //QT5 gameList << translatedKey;
@@ -230,7 +230,6 @@ int main( int argc, char **argv )
 
     QString testdir = parser.value(QStringLiteral("testdir"));
     if ( !testdir.isEmpty() ) {
-       qsrand(std::time(nullptr));
        if ( parser.isSet(QStringLiteral("generate")) ) {
           for (int dealer = 0; dealer < 20; dealer++) {
               DealerScene *f = getDealer( dealer, QString() );
@@ -239,7 +238,7 @@ int main( int argc, char **argv )
               QElapsedTimer mytime;
               while (count) {
                 if (f->deck()) f->deck()->stopAnimations();
-                int i = qrand() % INT_MAX;
+                int i = QRandomGenerator::global()->bounded(INT_MAX);
                 f->startNew( i );
                 mytime.start();
                 f->solver()->translate_layout();
@@ -321,7 +320,7 @@ int main( int argc, char **argv )
     }
 
     QString gametype = parser.value(QStringLiteral("gametype")).toLower();
-    QFile savedState( QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + saved_state_file);
+    QFile savedState( QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1String("/" saved_state_file));
 
     MainWindow *w = new MainWindow;
     if (!parser.positionalArguments().isEmpty())
